FromRow

Trait FromRow 

pub trait FromRow
where Self: Sized,
{ type Err; // Required method fn from_str_iter<'a, I>(row: I) -> Result<Self, Self::Err> where I: Iterator<Item = &'a Value>; }
Converts a row of Value cells into a typed Rust value.

Required Associated Types

type Err

Conversion error type.

Required Methods

fn from_str_iter<'a, I>(row: I) -> Result<Self, Self::Err>
where I: Iterator<Item = &'a Value>,

Errors

Returns an error when the row values cannot be converted into Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors